==============================
Presentations and Publications
==============================


FY20 DOE Presentation
---------------------

This document is a link to the Fiscal Year 2020 DOE presentation on the first prototype
of the model.
:download:`PDF <../../presentation_material/operations_and_maintenance_model_FY20.pdf>`


Code-to-Code Comparison
-----------------------

This document serves as a demonstration of the capabilities of this work in reference to
two major works to document simulated O&M results from various industry and research
software systems. Here we compare our software to the published results from
Dinwoodie, et al., 2015 :footcite:`dinwoodie2015reference` and IEA, 2016
:footcite:`smart2016iea`.
:download:`PDF <../../presentation_material/code_comparison.pdf>`


IEA Task 26 Presentation
------------------------

This presentation was given to the IEA Task Force responsible for :footcite:`smart2016iea`
as a demonstration of NREL's efforts on O&M model development.
:download:`PDF <../../presentation_material/WOMBAT_IEA_task_26_presentation_6_May_2021.pdf>`


References
^^^^^^^^^^
.. footbibliography::
